@@ -18,39 +18,40 @@ function(data, param, alpha = 0.1, hide.outliers = FALSE,
   
   # internal functions 
   # creates design matrices for contingency tables with n = #rows, p = #columns
-  create.X <- function(n, p) {
-    X0 <- rep(1, n*p) # first row 
-    X11 <- kronecker(diag(1,n-1), t(rep(1,p)))
-    X12 <- matrix(rep(-1, p*(n-1)), nrow=n-1, ncol=p)
-    
-    X1 <- cbind(X11, X12) # first block
-    
-    X21 <- cbind(diag(1, p-1), rep(-1, p-1))
-    X22 <- X21
-    
-    for(i in 1:(n-1)) X21 <- cbind(X21, X22) # second block
-    
-    rbind(X0, X1, X21)
-  }
+#   create.X <- function(n, p) {
+#     X0 <- rep(1, n*p) # first row 
+#     X11 <- kronecker(diag(1,n-1), t(rep(1,p)))
+#     X12 <- matrix(rep(-1, p*(n-1)), nrow=n-1, ncol=p)
+#     
+#     X1 <- cbind(X11, X12) # first block
+#     
+#     X21 <- cbind(diag(1, p-1), rep(-1, p-1))
+#     X22 <- X21
+#     
+#     for(i in 1:(n-1)) X21 <- cbind(X21, X22) # second block
+#     
+#     rbind(X0, X1, X21)
+#   }
   
   # preprocessing
-  i1 <- min(dim(data))
-  i2 <- max(dim(data)) 
-  if (dim(data)[1] > dim(data)[2]) data <- t(data)
-  # then data is defined as in Kuhnt et al. (2012)
-  
-  XDesi <- create.X(i1, i2) # creates a design matrix with i1+i2-1 rows, i1*i2 columns
+#  i1 <- min(dim(data))
+  i1 <- dim(data)[1]
+#  i2 <- max(dim(data)) 
+  i2 <- dim(data)[2] 
+#  if (dim(data)[1] > dim(data)[2]) data <- t(data)
   
+  XDesi <- createDesMat(i1, i2) # creates a design matrix with i1+i2-1 rows, i1*i2 columns
+  tXDesi <- t(XDesi)
   if (identical(all.equal(param[1], "ML"), TRUE)){ # Compute the ML estimator
-    temp <- glm.fit(t(XDesi), c(t(data)), family=poisson(log))
+    temp <- glm.fit(tXDesi, c(data), family = poisson(log))
     STmator <- t(temp$coefficients)
     param.temp <- t(temp$fitted.values)
   }
   
   if (identical(all.equal(param[1], "L1"), TRUE)){  # Compute the L1 estimator 
-    STmator <- t(rq.fit.fnc(t(XDesi), c(t(log(data))), R=t(XDesi), r=rep(1,dim(XDesi)[2]),
+    STmator <- t(rq.fit.fnc(tXDesi, c(log(data)), R = tXDesi, r = rep(1, dim(XDesi)[2]),
                             eps=1e-05)$coefficients)
-    param.temp <- exp(t(t(XDesi) %*% t(STmator)))
+    param.temp <- exp(STmator %*% XDesi)
   }
   
   if (identical(all.equal(param[1], "MP"), TRUE)) param.temp <- data - medpolish(data)$residuals
@@ -69,5 +70,4 @@ function(data, param, alpha = 0.1, hide.outliers = FALSE,
         identical(all.equal(show.estimates, TRUE), TRUE)) return(temp[temp[,2] == FALSE, c(1,3)])
   if (identical(all.equal(hide.outliers, TRUE), TRUE) & 
         identical(all.equal(show.estimates, FALSE), TRUE)) return(temp[temp[,2] == FALSE, 1])
-}
-
+}
\ No newline at end of file
