@@ -1,7 +1,7 @@
 aout.mvnorm <-
 function(data, param, alpha = 0.1, hide.outliers = FALSE){
   # check arguments
-  if (length(param) != 2) 
+  if (!identical(all.equal(length(param), 2), TRUE)) 
     stop("param must be a list with two elements.")
   if (!is.vector(param[[1]]))
     stop("First entry of param must be the mean vector.")
@@ -10,7 +10,7 @@ function(data, param, alpha = 0.1, hide.outliers = FALSE){
   if (is.data.frame(data)) as.matrix(data)
   if (!is.matrix(data)) 
     stop("data must be a data.frame or matrix.")
-  if (length(alpha) != 1 | alpha <= 0 | alpha >= 1) 
+  if (!identical(all.equal(length(alpha), 1), TRUE) | alpha <= 0 | alpha >= 1) 
     stop("alpha must be a real number between 0 and 1, but it is ", alpha, ".")
   # end check arguments
   # determine the outlier region
@@ -23,6 +23,6 @@ function(data, param, alpha = 0.1, hide.outliers = FALSE){
   temp.region <- qchisq(df = d, 1 - alpha)
   # give the results of the analysis
   temp <- data.frame(data = data, is.outlier = (te1 > temp.region))
-  if (hide.outliers == FALSE) temp
+  if (identical(all.equal(hide.outliers, FALSE), TRUE)) temp
   else temp[temp[,d+1] == FALSE, -(d+1)]
 }
